@@ -103,7 +103,7 @@ class DistributionSheet(Sheet):
                 DataBlock(
                     text_lines=[
                         TextLine(
-                            text_lines=self.sheet_reader.read_cell(
+                            text=self.sheet_reader.read_cell(
                                 row=row_index,
                                 col=col_index,
                             ).value
